# Copyright (c) 2025 Dexmate CORPORATION & AFFILIATES. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 with Commons Clause License
# Condition v1.0 [see LICENSE for details].

"""Miscellaneous robot component configurations."""

import os
from dataclasses import dataclass

from dexcontrol.utils.constants import DISABLE_HEARTBEAT_ENV_VAR


@dataclass
class BatteryConfig:
    _target_: str = "dexcontrol.core.misc.Battery"
    state_sub_topic: str = "state/bms"


@dataclass
class EStopConfig:
    _target_: str = "dexcontrol.core.misc.EStop"
    state_sub_topic: str = "state/estop"
    estop_query_name: str = "system/estop"


@dataclass
class HeartbeatConfig:
    _target_: str = "dexcontrol.core.misc.Heartbeat"
    heartbeat_topic: str = "/heartbeat"
    timeout_seconds: float = 1.0
    enabled: bool = True  # Can be disabled via DEXCONTROL_DISABLE_HEARTBEAT=1

    def __post_init__(self):
        """Check environment variable to disable heartbeat monitoring."""
        if os.getenv(DISABLE_HEARTBEAT_ENV_VAR, "0").lower() in ("1", "true", "yes"):
            self.enabled = False
